Class extends Part

Class constructor($spec : Object; $style : Object; $userActions : Object)
	
	Super:C1705("toolbar"; "tb_"; $spec; $style)
	
	This:C1470.toolsets:=New collection:C1472()
	
	var $toolsetSpec : Object
	For each ($toolsetSpec; This:C1470.spec["toolsets"])
		
		// In JSON schema it is not possible to validate uniqueness of
		// specific property values in an array, so we check for unique
		// toolset names manually.
		
		var $toolsetName : Text
		$toolsetName:=$toolsetSpec["name"]
		
		If (This:C1470.toolsets.query("name = :1"; $toolsetName).pop()=Null:C1517)
			
			var $toolset : cs:C1710.Toolset
			$toolset:=cs:C1710.Toolset.new($toolsetName; $toolsetSpec; $style; $userActions)
			
			If ($toolset.validate())
				This:C1470.toolsets.push($toolset)
			End if 
			
		End if 
		
	End for each 
	
	
Function validate()->$valid : Boolean
	
	$valid:=(This:C1470.toolsets.length>0)
	
	
Function effectivelyVisible()->$visible : Boolean
	
	$visible:=This:C1470.visible
	If ($visible)
		$visible:=(This:C1470.toolsets.query("visible = :1"; True:C214).length>0)
	End if 
	
	
Function layout($controlWidth : Integer; $controlHeight : Integer; \
$originX : Integer; $originY : Integer)
	
	var $toolbarStyle; $toolsetStyle; $toolStyle; $inputStyle : Object
	$toolbarStyle:=This:C1470.style.toolbar
	$toolsetStyle:=This:C1470.style.toolset
	$toolStyle:=This:C1470.style.tool
	$inputStyle:=This:C1470.style.input
	
	// Query visible toolsets
	var $visibleToolsets : Collection
	$visibleToolsets:=This:C1470.toolsets.query("visible = :1"; True:C214)
	
	var $toolbarVisible : Boolean
	$toolbarVisible:=This:C1470.visible & ($visibleToolsets.length>0)
	
	// =======================================================
	// 1st pass: set width/height of toolsets
	
	var $idx : Integer
	For ($idx; 0; This:C1470.toolsets.length-1)
		
		var $toolset : cs:C1710.Toolset
		$toolset:=This:C1470.toolsets[$idx]
		
		If ($toolbarVisible & $toolset.visible)
			
			var $toolPaddingX : Integer
			$toolPaddingX:=$toolStyle.paddingX
			
			var $toolsetWidth : Integer
			$toolsetWidth:=$toolPaddingX
			
			var $tool : cs:C1710.Tool
			For each ($tool; $toolset.tools)
				
				var $toolWidth; $toolHeight : Integer
				If ($tool.type="input")
					$toolWidth:=Choose:C955($tool.width#Null:C1517; $tool.width; $inputStyle.width)
					$toolHeight:=Choose:C955($tool.height#Null:C1517; $tool.height; $inputStyle.height)
				Else 
					var $menuExtra : Integer
					$menuExtra:=Choose:C955($tool.items#Null:C1517; $toolStyle.menuExtra; 0)
					
					$toolWidth:=Choose:C955($tool.width#Null:C1517; $tool.width; $toolStyle.width+$menuExtra)
					$toolHeight:=Choose:C955($tool.height#Null:C1517; $tool.height; $toolStyle.height)
				End if 
				
				$tool.bounds:=cs:C1710.Rect.new(0; 0; $toolWidth; $toolHeight)
				
				$toolsetWidth:=$toolsetWidth+$toolWidth+$toolPaddingX
				
			End for each 
			
			$toolset.bounds:=cs:C1710.Rect.new(0; 0; $toolsetWidth; $toolsetStyle.height)
			
		Else 
			$toolset.bounds:=Null:C1517
		End if 
		
	End for 
	
	
	// =======================================================
	// 2nd pass: arrange toolsets in rows (set x/y)
	
	C_LONGINT:C283($usableWidth; $remainingWidth)
	$usableWidth:=$controlWidth-(2*$toolsetStyle.paddingX)
	$remainingWidth:=$usableWidth
	
	C_LONGINT:C283($curX; $curY)
	$curX:=$originX+$toolsetStyle.paddingX
	$curY:=$originY+$toolsetStyle.paddingY
	
	For ($idx; 0; This:C1470.toolsets.length-1)
		
		var $toolset : cs:C1710.Toolset
		$toolset:=This:C1470.toolsets[$idx]
		
		If ($toolbarVisible & $toolset.visible)
			
			var $toolsetWidth : Integer
			$toolsetWidth:=$toolset.bounds.width
			
			C_BOOLEAN:C305($newRow)
			$newRow:=($toolsetWidth>$remainingWidth)
			If ($newRow)
				
				$remainingWidth:=$usableWidth
				
				$curX:=$originX+$toolsetStyle.paddingX
				$curY:=$curY+$toolsetStyle.height+$toolsetStyle.paddingY
				
				$toolset.bounds.x:=$curX
				$toolset.bounds.y:=$curY
				
			Else 
				
				$toolset.bounds.x:=$curX
				$toolset.bounds.y:=$curY
				
				$curX:=$curX+$toolsetWidth+$toolsetStyle.paddingX
				$remainingWidth:=$remainingWidth-$toolsetWidth-$toolsetStyle.paddingX
				
			End if 
			
		Else 
			$toolset.bounds:=Null:C1517
		End if 
		
	End for 
	
	// =======================================================
	// 3rd pass: layout tools
	
	For ($idx; 0; This:C1470.toolsets.length-1)
		
		var $toolset : cs:C1710.Toolset
		$toolset:=This:C1470.toolsets[$idx]
		
		If ($toolbarVisible & $toolset.visible)
			
			$curX:=$toolset.bounds.x
			$curY:=$toolset.bounds.y
			
			var $tool : cs:C1710.Tool
			For each ($tool; $toolset.tools)
				
				var $toolPaddingX; $toolPaddingY : Integer
				$toolPaddingX:=$toolStyle.paddingX
				If ($tool.type="input")
					$toolPaddingY:=$inputStyle.paddingY
				Else 
					$toolPaddingY:=$toolStyle.paddingY
				End if 
				
				var $toolX; $toolY : Integer
				$toolX:=$curX+$toolPaddingX
				$toolY:=$curY+$toolpaddingY
				
				$tool.bounds.x:=$toolX
				$tool.bounds.y:=$toolY
				
				$curX:=$toolX+$tool.bounds.width
				
			End for each 
			
		End if 
		
	End for 
	
	// Fimally, update toolbar bounds
	var $lastVisibleToolset : cs:C1710.Toolset
	If ($toolbarVisible)
		$lastVisibleToolset:=Choose:C955($visibleToolsets.length>0; $visibleToolsets[$visibleToolsets.length-1]; Null:C1517)
	Else 
		$lastVisibleToolset:=Null:C1517
	End if 
	If ($lastVisibleToolset#Null:C1517)
		This:C1470.bounds:=cs:C1710.Rect.new($originX; $originY; \
			$controlWidth; \
			($lastVisibleToolset.bounds.y-$originY)+$lastVisibleToolset.bounds.height+$toolsetStyle.paddingY)
	Else 
		This:C1470.bounds:=Null:C1517
	End if 
	
	
Function build()
	
	var $toolset : cs:C1710.Toolset
	For each ($toolset; This:C1470.toolsets)
		
		OBJECT DUPLICATE:C1111(*; "toolset"; $toolset.formObject)
		
		var $tool : cs:C1710.Tool
		For each ($tool; $toolset.tools)
			
			var $templateObject : Text
			Case of 
				: ($tool.type="button")
					$templateObject:="tool_button"
				: ($tool.type="check")
					$templateObject:="tool_check"
				: ($tool.type="radio")
					$templateObject:="tool_radio"
				: ($tool.type="input")
					Case of 
						: ($tool.input.valueType="integer")
							$templateObject:="tool_integer"
						: ($tool.input.valueType="number")
							$templateObject:="tool_number"
						: ($tool.input.valueType="percent")
							$templateObject:="tool_percent"
					End case 
			End case 
			
			If ($templateObject#"")
				
				OBJECT DUPLICATE:C1111(*; $templateObject; $tool.formObject)
				
				Case of 
					: ($tool.type="button") | ($tool.type="check") | ($tool.type="radio")
						
						var $format : Text
						var $elems : Collection
						
						If ($tool.icon#Null:C1517)
							
							$format:=OBJECT Get format:C894(*; $tool.formObject)
							$elems:=Split string:C1554($format; ";")
							$elems[1]:="path:"+$tool.icon
							$elems[5]:="1"
							$format:=$elems.join(";")
							OBJECT SET FORMAT:C236(*; $tool.formObject; $format)
							
						End if 
						
						If ($tool.items#Null:C1517)
							
							$format:=OBJECT Get format:C894(*; $tool.formObject)
							$elems:=Split string:C1554($format; ";")
							$elems[10]:="1"
							$format:=$elems.join(";")
							OBJECT SET FORMAT:C236(*; $tool.formObject; $format)
							
						End if 
						
						OBJECT SET ENABLED:C1123(*; $tool.formObject; False:C215)
						
					: ($tool.type="input")
						
						Case of 
							: ($tool.input.valueType="integer") | ($tool.input.valueType="number")
								
								If ($tool.input.minValue#Null:C1517)
									OBJECT SET MINIMUM VALUE:C1242(*; $tool.formObject; Num:C11($tool.input.minValue))
								End if 
								
								If ($tool.input.maxValue#Null:C1517)
									OBJECT SET MAXIMUM VALUE:C1244(*; $tool.formObject; Num:C11($tool.input.maxValue))
								End if 
								
						End case 
						
						OBJECT SET ENTERABLE:C238(*; $tool.formObject; False:C215)
						
				End case 
				
				OBJECT SET HELP TIP:C1181(*; $tool.formObject; $tool.title)
				
			End if 
			
		End for each 
		
	End for each 
	
	
Function apply()
	
	var $toolbarStyle; $toolsetStyle; $toolStyle; $inputStyle : Object
	$toolbarStyle:=This:C1470.style.toolbar
	$toolsetStyle:=This:C1470.style.toolset
	$toolStyle:=This:C1470.style.tool
	$inputStyle:=This:C1470.style.input
	
	var $toolbarVisible : Boolean
	$toolbarVisible:=This:C1470.effectivelyVisible()
	
	var $toolset : cs:C1710.Toolset
	var $tool : cs:C1710.Tool
	
	For each ($toolset; This:C1470.toolsets)
		
		If ($toolbarVisible & $toolset.visible)
			
			var $toolsetBounds : cs:C1710.Rect
			$toolsetBounds:=$toolset.bounds
			
			OBJECT SET VISIBLE:C603(*; $toolset.formObject; True:C214)
			OBJECT SET COORDINATES:C1248(*; $toolset.formObject; \
				$toolsetBounds.x; $toolsetBounds.y; \
				$toolsetBounds.x+$toolsetBounds.width; $toolsetBounds.y+$toolsetBounds.height)
			
			For each ($tool; $toolset.tools)
				
				var $toolBounds : cs:C1710.Rect
				$toolBounds:=$tool.bounds
				
				OBJECT SET VISIBLE:C603(*; $tool.formObject; True:C214)
				OBJECT SET COORDINATES:C1248(*; $tool.formObject; \
					$toolBounds.x; $toolBounds.y; \
					$toolBounds.x+$toolBounds.width; $toolBounds.y+$toolBounds.height)
				
			End for each 
			
		Else 
			OBJECT SET VISIBLE:C603(*; $toolset.formObject; False:C215)
			For each ($tool; $toolset.tools)
				OBJECT SET VISIBLE:C603(*; $tool.formObject; False:C215)
			End for each 
		End if 
		
	End for each 
	
	// Separator
	
	OBJECT SET VISIBLE:C603(*; "toolbar_sep"; $toolbarVisible)
	If ($toolbarVisible)
		
		var $left; $top; $right; $bottom : Integer
		$left:=This:C1470.bounds.x
		$top:=This:C1470.bounds.y+This:C1470.bounds.height
		$right:=$left+This:C1470.bounds.width
		$bottom:=$top
		
		OBJECT SET COORDINATES:C1248(*; "toolbar_sep"; $left; $top; $right; $bottom)
		
	End if 
	
	
Function getToolset($name : Text)->$toolset : cs:C1710.Toolset
	
	$toolset:=This:C1470.toolsets.query("name = :1"; $name).pop()
	
	
Function getToolFromFormObject($formObject : Text)->$tool : cs:C1710.Tool
	
	var $toolset : cs:C1710.Toolset
	For each ($toolset; This:C1470.toolsets) While ($tool=Null:C1517)
		$tool:=$toolset.tools.query("formObject = :1"; $formObject).pop()
	End for each 
	
	