//%attributes = {"shared":true}
C_TEXT:C284($1;$controlName)  // @param: The name of the ``ImgControl`` form object.
C_OBJECT:C1216($2;$configObj)  // @param: The configuration object. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Setup a ImgControl form object with a configuration object.

  // @doc: Setup the ``ImgControl`` form object named ``controlName``
  // with a configuration object.
  //
  // Typically called during the ``On Load`` event of the host form
  // right after a successful call to :cc4d:cmethod:`ImgControl_Initialize`.
  // Can also be called while the form is running in order to change the
  // configuration "on the fly".
  // 
  // If ``configObj`` is an undefined object (or omitted),
  // The method looks for ``Q2Pix/Q2ImgControl/Configs/<controlName>.json``
  // in the host database's ``Resources`` folder. If the file exists
  // the ``ImgControl`` configuration is loaded from that file.
  //
  // If no file exists at that location, the default configuration is
  // loaded from ``Q2Pix/Q2ImgControl/Configs/ImgControl.json`` in the
  // component's ``Resources`` folder.
  //
  // .. note:: The format of the JSON configuration file will be finalized
  //           and documented in a subsequent beta.
  //

ASSERT:C1129(Count parameters:C259>=1)

$controlName:=$1
If (Count parameters:C259>1)
	$configObj:=OB Copy:C1225($2)
End if 
$success:=0

C_POINTER:C301($controlPtr)
$controlPtr:=OBJECT Get pointer:C1124(Object named:K67:5;$controlName)

ASSERT:C1129(Not:C34(Is nil pointer:C315($controlPtr)))
ASSERT:C1129(Type:C295($controlPtr->)=Is object:K8:27)

If ($configObj=Null:C1517)
	$configObj:=Comp_GetResJSONObject ("NG/Configs/"+$controlName+".json")
	If ($configObj=Null:C1517)
		  //$configObj:=Comp_GetResJSONObject ("NG/Configs/BuiltinConfig.json")
		$configObj:=Comp_GetResJSONObject ("NG/DefaultConfig.json")
	End if 
End if 

If ($configObj#Null:C1517)
	
	C_OBJECT:C1216($context)
	$context:=$controlPtr->
	
	If ($context#Null:C1517)
		
		C_LONGINT:C283($left;$top;$right;$bottom)
		OBJECT GET COORDINATES:C663(*;$context.controlName;$left;$top;$right;$bottom)
		
		C_LONGINT:C283($controlWidth;$controlHeight)
		$controlWidth:=$right-$left
		$controlHeight:=$bottom-$top
		
		  //C_OBJECT($validConfig)
		  //$validConfig:=ImgCtlNG_ValidConfig ($configObj)
		
		$context.metrics:=ImgCtlNG_GetMetrics 
		
		$context.config:=ICNG_Config_Create ($configObj)
		If ($context.config.sidebar.width=Null:C1517)
			$context.config.sidebar.width:=$context.metrics.sidebar.defaultWidth
		End if 
		$context.formControls:=ImgCtlNG_BuildFormControls ($context.config)
		
		$context.layout:=ImgCtlNG_BuildLayout ($context.config;$context.metrics;$controlWidth;$controlHeight)
		$context.state.layoutUpdated:=True:C214
		
		  //$context.controls:=ImgCtlNG_BuildControlDict ($context.layout)
		$context.form:=ImgCtlNG_BuildForm ($context.config;$context.metrics;$context.layout;$controlWidth;$controlHeight)
		  //$context.controlStates:=ImgCtlNG_BuildControlStates ($context.config)
		
		$context.controlValues:=New object:C1471()
		$context.controlStates:=New object:C1471()
		
		If ((FORM Get current page:C276=$context.formPage) | ($context.formPage=0))
			
			C_OBJECT:C1216($subForm)
			$subForm:=$context.form
			
			OBJECT SET SUBFORM:C1138(*;$controlName;$subForm)
			
			$context.state.formSet:=True:C214
			$context.state.layoutApplied:=False:C215
			
			  //ImgCtlCtx_UpdateState ($context)
			CALL FORM:C1391(Current form window:C827;"ImgCtlCtx_UpdateState";$context)
			  //$context.state.controlStateUpdated:=True
			
		Else 
			$context.state.formSet:=False:C215
			$context.state.layoutUpdated:=False:C215
			$context.state.layoutApplied:=False:C215
		End if 
		
		ImgCtlNG_ApplyLayout_PlugArea ($context)
		
		$success:=Num:C11($context.form#Null:C1517)
		
	End if 
	
End if 

$0:=$success
