//%attributes = {"shared":true}
C_TEXT:C284($1;$controlName)  // @param: The name of the ``ImgControl`` form object.
C_LONGINT:C283($0;$msgCount)  // @param: The number of processed messages

  // @desc: Process ImgControl messages.

  // @doc: Process messages for the ``ImgControl`` named ``controlName``.
  // 
  // The ``ImgControl`` object uses an internal messaging system for its various
  // internal parts to communicate with the host form. The processing of these
  // messages is vital for the correct operation of the control and this method
  // does the necessary work.
  //
  // This method **must** be called from *two* places:
  //
  //    * From the object method of the ``controlName`` ``ImgControl`` during the ``kImgControlMessage`` event.
  //    * From the host form method during the ``On Timer`` event.
  //
  // The ``kImgControlMessage`` event in the object method is the result of internal messaging by means of the
  // ``CALL SUBFORM CONTAINER`` 4D method. That should be enough for the control's messaging,
  // but we have found out that under some circumstances messages may take a long time
  // to arrive from the subform context to the object method. That's why the call from the host form's
  // ``On Idle`` event is necessary.
  // 
  // When calling this method from the host's `On Timer`` event the method's result should be checked,
  // and if ``0`` the timer event be cancelled with ``SET TIMER(0)``. The internal messaging system
  // will re-enable the timer when a new message has to be delivered.
  //


ASSERT:C1129(Count parameters:C259=1)

$controlName:=$1
$msgCount:=0

C_OBJECT:C1216($context)
$context:=Control_GetObjectContext ($controlName)
If (OB Is defined:C1231($context))
	
	C_TEXT:C284($handlerMethod)
	$handlerMethod:=OB Get:C1224($context;"_message_handler";Is text:K8:3)
	
	ARRAY OBJECT:C1221($messages;0)
	Queue_GetMessages ($context;->$messages)
	$msgCount:=Size of array:C274($messages)
	
	C_LONGINT:C283($idx)
	
	C_BOOLEAN:C305($messageHandlerValid)
	
	For ($idx;1;$msgCount)
		
		C_OBJECT:C1216($aMessage)
		$aMessage:=$messages{$idx}
		
		C_BOOLEAN:C305($callHandler)
		$callHandler:=True:C214
		
		C_LONGINT:C283($handlerResult)
		$handlerResult:=0
		
		If ($handlerMethod#"")
			EXECUTE METHOD:C1007($handlerMethod;$handlerResult;$controlName;$aMessage;"pre")
			$callHandler:=($handlerResult=0)
		End if 
		
		If ($callHandler)
			Control_HandleMessage ($controlName;$aMessage)
			
			If ($handlerMethod#"")
				EXECUTE METHOD:C1007($handlerMethod;$handlerResult;$controlName;$aMessage;"post")
			End if 
			
		End if 
		
	End for 
	
End if 

$0:=$msgCount
