//%attributes = {"shared":true}
C_TEXT:C284($1;$controlName)  // @param: The name of the ``ImgControl`` form object.
C_OBJECT:C1216($2;$configObj)  // @param: The configuration object. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Setup a ImgControl form object with a configuration object.

  // @doc: Setup the ``ImgControl`` form object named ``controlName``
  // with a configuration object.
  //
  // Typically called during the ``On Load`` event of the host form
  // right after a successful call to :cc4d:cmethod:`ImgControl_Initialize`.
  // Can also be called while the form is running in order to change the
  // configuration "on the fly".
  // 
  // If ``configObj`` is an undefined object (or omitted),
  // The method looks for ``Q2Pix/Q2ImgControl/Configs/<controlName>.json``
  // in the host database's ``Resources`` folder. If the file exists
  // the ``ImgControl`` configuration is loaded from that file.
  //
  // If no file exists at that location, the default configuration is
  // loaded from ``Q2Pix/Q2ImgControl/Configs/ImgControl.json`` in the
  // component's ``Resources`` folder.
  //
  // .. note:: The format of the JSON configuration file will be finalized
  //           and documented in a subsequent beta.
  //

ASSERT:C1129(Count parameters:C259>=1)

$controlName:=$1
If (Count parameters:C259>1)
	$configObj:=OB Copy:C1225($2)
End if 
$success:=0

C_POINTER:C301($controlPtr)
$controlPtr:=OBJECT Get pointer:C1124(Object named:K67:5;$controlName)

ASSERT:C1129(Not:C34(Is nil pointer:C315($controlPtr)))
ASSERT:C1129(Type:C295($controlPtr->)=Is text:K8:3)

If (Not:C34(OB Is defined:C1231($configObj)))
	$configObj:=Comp_GetResJSONObject ("Configs/"+$controlName+".json")
	If (Not:C34(OB Is defined:C1231($configObj)))
		$configObj:=Comp_GetResJSONObject ("Configs/ImgControl.json")
	End if 
End if 

If (OB Is defined:C1231($configObj))
	
	C_OBJECT:C1216($context)
	$context:=Control_GetObjectContext ($controlName)
	If (OB Is defined:C1231($context))
		
		C_BOOLEAN:C305($isInitialConfig)
		$isInitialConfig:=Not:C34(OB Is defined:C1231($context;"_config"))
		If (Not:C34($isInitialConfig))
			EXECUTE METHOD IN SUBFORM:C1085($controlName;"Toolbar_Reset_S";*;$context)
		End if 
		
		C_OBJECT:C1216($cmdRegistry)
		$cmdRegistry:=OB_New 
		
		C_OBJECT:C1216($menubarInfo;$toolbarInfo)
		$menubarInfo:=Menubar_Setup ($configObj;$cmdRegistry)
		$toolbarInfo:=Toolbar_Setup ($configObj;$cmdRegistry)
		
		OB SET:C1220($context;"_config";$configObj)
		OB SET:C1220($context;"_menubar";$menubarInfo)
		OB SET:C1220($context;"_toolbar";$toolbarInfo)
		OB SET:C1220($context;"_commands";$cmdRegistry)
		
		If ($isInitialConfig)
			
			EXECUTE METHOD IN SUBFORM:C1085($controlName;"Menubar_Build_S";*;$context)
			EXECUTE METHOD IN SUBFORM:C1085($controlName;"Toolbar_Build_S";*;$context;$controlPtr)
			
			ImgControl_UpdateLayout ($controlName)
			
			C_OBJECT:C1216($message)
			OB SET:C1220($message;"what";"_setup")
			ImgControl_PostMessage ($controlName;$message)
			
		Else 
			
			C_OBJECT:C1216($msg)
			OB SET:C1220($msg;"what";"_build")
			ImgControl_PostMessage ($controlName;$msg)
			
		End if 
		
		$success:=1
		
	End if 
	
End if 

$0:=$success
