//%attributes = {"shared":true}
C_TEXT:C284($1;$controlName)  // @param: The name of the ``ImgControl`` form object.
C_TEXT:C284($2;$configName)  // @param: The configuration name. @optional.
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Setup a ImgControl form object with a named configuration.

  // @doc: Setup the ``ImgControl`` form object named ``controlName``
  // with a named configuration.
  //
  // Typically called during the ``On Load`` event of the host form
  // right after a successful call to :cc4d:cmethod:`ImgControl_Initialize`.
  // Can also be called while the form is running in order to change the
  // configuration "on the fly".
  // 
  // The method looks for ``Q2Pix/Q2ImgControl/Configs/<configName>.json``
  // in the host database's ``Resources`` folder. If the file exists
  // the ``ImgControl`` configuration is loaded from that file.
  //
  // If no file exists at that location or ``<configName>`` is empty (or omitted),
  // configuration is delegated to :cc4d:cmethod:`ImgControl_Setup`.
  //
  // .. note:: The format of the JSON configuration object will be finalized
  //           and documented in a subsequent beta.
  //

ASSERT:C1129(Count parameters:C259>=1)

$controlName:=$1
If (Count parameters:C259>1)
	$configName:=$2
End if 
$success:=0

C_POINTER:C301($controlPtr)
$controlPtr:=OBJECT Get pointer:C1124(Object named:K67:5;$controlName)

ASSERT:C1129(Not:C34(Is nil pointer:C315($controlPtr)))
ASSERT:C1129(Type:C295($controlPtr->)=Is text:K8:3)

C_OBJECT:C1216($configObj)
If ($configName#"")
	$configObj:=Comp_GetResJSONObject ("Configs/"+$configName+".json")
End if 
$success:=ImgControl_Setup ($controlName;$configObj)

$0:=$success
