//%attributes = {"shared":true}
C_LONGINT:C283($1;$areaRef)  // @param: The image area reference
C_TEXT:C284($2;$propName)  // @param: The property name.
C_POINTER:C301($3;$propValuePtr)  // @param: A pointer to the variable holding the property's value.
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Set the value of a plug-in area property.

  // @doc: Set the value of a plug-in area property.
  //
  // Parameter ``areaRef`` is the plug-in area reference.
  //
  // The name of the property to be set is specified by ``propName``.
  //
  // The value of the property is in the variable pointed to by ``propValuePtr``.
  // The type of the variable must match that of the property.
  // The properties defined by the plug-in area are described in the following table.
  //
  // .. include:: /_shared/ImgArea_Properties.rsti
  //
  // .. note:: In addition to the properties defined by the plug-in area, applications can attach
  //           and access custom properties to a plug-in area for their own use.
  //           The type of plug-in area properties can be any of: ``Boolean``, ``Longint``,
  //           ``Real``, ``Text``, ``Object``, ``Boolean array``, ``Longint array``,
  //           ``Real array``, ``Text array``, ``Object array``.
  //
  // .. note:: This method is a convenience wrapper for the :cc4d:xmethod:`ImgArea_SetProperty_JSN` plug-in method
  //           that serializes the property to JSON.


ASSERT:C1129(Count parameters:C259=3)

$areaRef:=$1
$propName:=$2
$propValuePtr:=$3
$success:=0

C_TEXT:C284($valueJSON)
$valueJSON:=""

C_LONGINT:C283($valueType)
$valueType:=Type:C295($propValuePtr->)

Case of 
	: (($valueType=Is boolean:K8:9)\
		 | ($valueType=Is longint:K8:6)\
		 | ($valueType=Is real:K8:4)\
		 | ($valueType=Is text:K8:3)\
		 | ($valueType=Is object:K8:27))
		
		$valueJSON:=JSON Stringify:C1217($propValuePtr->)
		
	: (($valueType=Boolean array:K8:21)\
		 | ($valueType=LongInt array:K8:19)\
		 | ($valueType=Real array:K8:17)\
		 | ($valueType=Text array:K8:16)\
		 | ($valueType=Object array:K8:28))
		
		$valueJSON:=JSON Stringify array:C1228($propValuePtr->)
		
End case 

ImgArea_SetProperty_JSN:P11667:61 ($areaRef;$propName;$valueJSON)
$success:=Num:C11(ImgErr_GetCode =0)

$0:=$success
