//%attributes = {"shared":true}
C_TEXT:C284($1; $docRef)  // @param: The image document reference.
C_LONGINT:C283($2; $frameIdx)  // @param: The image frame index. @optional

// @desc: Displays an image document information dialog.

// @doc: Displays an image document information dialog.
//
// Parameter ``docRef`` is the image document reference.
//
// Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
// argument is the same as passing ``1``.

ASSERT:C1129(Count parameters:C259>=1)

$docRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
Else 
	$frameIdx:=0
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

C_LONGINT:C283($frameCount)
$frameCount:=ImgDoc_GetFrameCount:P11667:11($docRef)

If (($frameCount>0) & ($frameIdx>0) & ($frameIdx<=$frameCount))
	
	C_OBJECT:C1216($docProps)
	$docProps:=ImgDoc_GetProperties($docRef)
	
	C_TEXT:C284($filePath)
	$filePath:=OB Get:C1224($docProps; "FilePath"; Is text:K8:3)
	
	C_LONGINT:C283($fileSize)
	$fileSize:=OB Get:C1224($docProps; "FileSize"; Is longint:K8:6)
	
	C_TEXT:C284($format)
	$format:=ImgDoc_GetFormat:P11667:9($docRef)
	
	C_TEXT:C284($formatName)
	$formatName:=ImgFormat_GetName($format)
	
	var $infoItems : Collection
	$infoItems:=New collection:C1472()
	
	If ($filePath#"")
		$infoItems.push(New object:C1471("label"; "File path:"; "value"; $filePath))
	End if 
	
	$infoItems.push(New object:C1471("label"; "Document type:"; "value"; $formatName))
	
	$infoItems.push(New object:C1471("label"; "File size:"; "value"; String:C10($fileSize; "###,###,##0 bytes")))
	
	If ($filePath#"")
		
		var $file : 4D:C1709.File
		$file:=File:C1566($filePath; fk posix path:K87:1)
		
		C_DATE:C307($creationDate; $modificationDate)
		C_TIME:C306($creationTime; $modificationTime)
		$creationDate:=$file.creationDate
		$creationTime:=$file.creationTime
		$modificationDate:=$file.modificationDate
		$modificationTime:=$file.modificationTime
		
		C_TEXT:C284($creationTimeStamp; $modificationTimeStamp)
		$creationTimeStamp:=String:C10($creationDate; Internal date abbreviated:K1:6)+" "+String:C10($creationTime; HH MM SS:K7:1)
		$modificationTimeStamp:=String:C10($modificationDate; Internal date abbreviated:K1:6)+" "+String:C10($modificationTime; HH MM SS:K7:1)
		
		$infoItems.push(New object:C1471("label"; "File creation date:"; "value"; $creationTimeStamp))
		
		$infoItems.push(New object:C1471("label"; "File modification date:"; "value"; $modificationTimeStamp))
		
	End if 
	
	$infoItems.push(New object:C1471("label"; ""; "value"; ""))
	
	If ($format="PDF")  // PDF document properties
		
		C_LONGINT:C283($pdfMetaCount)
		$pdfMetaCount:=0
		
		ARRAY TEXT:C222($pdfMetaKeys; 0)
		APPEND TO ARRAY:C911($pdfMetaKeys; "Title")
		APPEND TO ARRAY:C911($pdfMetaKeys; "Subject")
		APPEND TO ARRAY:C911($pdfMetaKeys; "Keywords")
		APPEND TO ARRAY:C911($pdfMetaKeys; "Author")
		APPEND TO ARRAY:C911($pdfMetaKeys; "Creator")
		APPEND TO ARRAY:C911($pdfMetaKeys; "Producer")
		
		C_TEXT:C284($pdfMetaProp)
		
		C_LONGINT:C283($idx)
		For ($idx; 1; Size of array:C274($pdfMetaKeys))
			$pdfMetaProp:=OB Get:C1224($docProps; $pdfMetaKeys{$idx}; Is text:K8:3)
			If ($pdfMetaProp#"")
				$infoItems.push(New object:C1471("label"; $pdfMetaKeys{$idx}+":"; "value"; $pdfMetaProp))
				$pdfMetaCount:=$pdfMetaCount+1
			End if 
		End for 
		
		$pdfMetaProp:=OB Get:C1224($docProps; "Version"; Is text:K8:3)
		If ($pdfMetaProp#"")
			$infoItems.push(New object:C1471("label"; "PDF version:"; "value"; $pdfMetaProp))
			$pdfMetaCount:=$pdfMetaCount+1
		End if 
		
		$pdfMetaProp:=OB Get:C1224($docProps; "CreationDate"; Is text:K8:3)
		If ($pdfMetaProp#"")
			$infoItems.push(New object:C1471("label"; "PDF creation date:"; "value"; $pdfMetaProp))
			$pdfMetaCount:=$pdfMetaCount+1
		End if 
		
		$pdfMetaProp:=OB Get:C1224($docProps; "ModDate"; Is text:K8:3)
		If ($pdfMetaProp#"")
			$infoItems.push(New object:C1471("label"; "PDF modification date:"; "value"; $pdfMetaProp))
			$pdfMetaCount:=$pdfMetaCount+1
		End if 
		
		If ($pdfMetaCount>0)
			$infoItems.push(New object:C1471("label"; ""; "value"; ""))
		End if 
		
	End if 
	
	If ($frameCount>1)
		
		$infoItems.push(New object:C1471(\
			"label"; Choose:C955($format="PDF"; "Page:"; "Frame:"); \
			"value"; String:C10($frameIdx)+" of "+String:C10($frameCount)))
		
	End if 
	
	C_OBJECT:C1216($pointSize)
	$pointSize:=ImgFrame_GetPointSize($docRef; $frameIdx)
	
	C_REAL:C285($pointWidth; $pointHeight)
	$pointWidth:=SizeObj_GetWidth($pointSize)
	$pointHeight:=SizeObj_GetHeight($pointSize)
	
	If ($format="PDF")
		
		$infoItems.push(New object:C1471(\
			"label"; "Page size:"; \
			"value"; String:C10(Choose:C955($pointSize["Width"]#Null:C1517; $pointSize["Width"]; 0); "### ##0.0")\
			+" x "\
			+String:C10(Choose:C955($pointSize["Height"]#Null:C1517; $pointSize["Height"]; 0); "### ##0.0")+" points"))
		
	Else 
		
		C_OBJECT:C1216($pixelSize)
		$pixelSize:=RasterFrame_GetPixelSize($docRef; $frameIdx)
		
		C_LONGINT:C283($pixelWidth; $pixelHeight)
		$pixelWidth:=SizeObj_GetWidth($pixelSize)
		$pixelHeight:=SizeObj_GetHeight($pixelSize)
		
		$infoItems.push(New object:C1471(\
			"label"; "Image size:"; \
			"value"; String:C10($pixelWidth)\
			+" x "\
			+String:C10($pixelHeight)+" pixels\r"\
			+String:C10($pointWidth; "### ##0.0")\
			+" x "+\
			String:C10($pointHeight; "### ##0.0")+" points"))
		
		C_OBJECT:C1216($dpiSize)
		$dpiSize:=RasterFrame_GetDPISize($docRef; $frameIdx)
		
		C_REAL:C285($dpiWidth; $dpiHeight)
		$dpiWidth:=SizeObj_GetWidth($dpiSize)
		$dpiHeight:=SizeObj_GetHeight($dpiSize)
		
		If ($dpiWidth=$dpiHeight)
			$infoItems.push(New object:C1471(\
				"label"; "Image resolution:"; \
				"value"; String:C10($dpiWidth; "### ##0.0")+" DPI"))
		Else 
			$infoItems.push(New object:C1471(\
				"label"; "Image resolution:"; \
				"value"; String:C10($dpiWidth; "### ##0.0")\
				+" x "\
				+String:C10($dpiHeight; "### ##0.0")+" DPI"))
		End if 
		
		C_OBJECT:C1216($frameProps)
		$frameProps:=ImgFrame_GetProperties($docRef; $frameIdx)
		
		var $orientation : Integer
		$orientation:=RasterFrame_GetOrientation($docRef; $frameIdx)
		If ($orientation>=kImgOrientationNormal) & ($orientation<=kImgRotatedRight)
			
			var $orientationName : Text
			Case of 
				: ($orientation=kImgOrientationNormal)
					$orientationName:="Normal"
				: ($orientation=kImgFlippedHorz)
					$orientationName:="Flipped horizontally"
				: ($orientation=kImgRotated180)
					$orientationName:="Rotated 180°"
				: ($orientation=kImgFlippedVert)
					$orientationName:="Flipped vertically"
				: ($orientation=kImgRotatedLeftFlippedVert)
					$orientationName:="Rotated 90° CCW and flipped vertically"
				: ($orientation=kImgRotatedLeft)
					$orientationName:="Rotated 90° CCW"
				: ($orientation=kImgRotatedRightFlippedVert)
					$orientationName:="Rotated 90° CW and flipped vertically"
				: ($orientation=kImgRotatedRight)
					$orientationName:="Rotated 90° CW"
			End case 
			
			$orientationName:=String:C10($orientation)+" ("+$orientationName+")"
			
			$infoItems.push(New object:C1471("label"; "Orientation:"; "value"; $orientationName))
		End if 
		
		If (OB Is defined:C1231($frameProps; "ColorModel"))
			$infoItems.push(New object:C1471(\
				"label"; "Color model:"; \
				"value"; OB Get:C1224($frameProps; "ColorModel"; Is text:K8:3)))
		End if 
		
		If (OB Is defined:C1231($frameProps; "ProfileName"))
			$infoItems.push(New object:C1471(\
				"label"; "Color profile:"; \
				"value"; OB Get:C1224($frameProps; "ProfileName"; Is text:K8:3)))
		End if 
		
	End if 
	
	var $dialogContext : Object
	$dialogContext:=New object:C1471()
	$dialogContext.infoItems:=$infoItems
	$dialogContext.window:=Open form window:C675("_ImgInfoNG"; Movable form dialog box:K39:8)
	
	SET WINDOW TITLE:C213($format+" Information"; $dialogContext.window)
	
	DIALOG:C40("_ImgInfoNG"; $dialogContext)
	
	CLOSE WINDOW:C154($dialogContext.window)
	
End if 

