//%attributes = {"shared":true}
C_TEXT:C284($1; $title)  // @param: The title of the file selection dialog. @optional
C_TEXT:C284($2; $defaultDir)  // @param: The default directory path. @optional
C_POINTER:C301($3; $formatArrayPtr)  // @param: Image file formats. @optional
C_TEXT:C284($0; $filePath)  // @param: The full pathname of the selected file in POSIX format.

// @desc: Prompts the user to select an image file through the standard
// file selection dialog.

// @doc: Prompts the user to select an image file through the standard
// file selection dialog. The file list is filtered to allow selection of images in one
// of the supported formats.
// 
// The title of the dialog can be specified with the ``title`` parameter.
// If omitted or empty, it defaults to "Open image...".
//
// Parameter ``defaultDir`` can be used to set the directory that will be
// displayed in the dialog. If omitted or empty, the dialog will display the
// last used directory.
//
// The image formats that will be displayed in the dialog can be customized
// via the ``formatArrayPtr`` parameter. If specified it must be a pointer to a text
// array containing the image format identifiers. If omitted or ``Nil``, all supported
// formats will be displayed.
//
// If the user successfully selects an image file, the file's full path in
// POSIX format is returned in ``filePath``. If the user cancels the dialog an
// empty string is returned.

If (Count parameters:C259>0)
	$title:=$1
End if 

If (Count parameters:C259>1)
	$defaultDir:=$2
End if 

If (Count parameters:C259>2)
	$formatArrayPtr:=$3
	ASSERT:C1129(Type:C295($formatArrayPtr->)=Text array:K8:16)
End if 

If ($title="")
	$title:="Open image..."
End if 

C_TEXT:C284($formatList)
If (Is macOS:C1572)
	$formatList:=ImgFormat_GetUTIFilter($formatArrayPtr)
Else 
	$formatList:=ImgFormat_GetFileExtFilter($formatArrayPtr)
End if 

C_TEXT:C284($file)
If ($defaultDir#"")
	$defaultDir:=Convert path POSIX to system:C1107($defaultDir)
	$file:=Select document:C905($defaultDir; $formatList; $title; 0)
Else 
	$file:=Select document:C905(11667; $formatList; $title; 0)
End if 

If (OK=1)
	$filePath:=Convert path system to POSIX:C1106(Document)
End if 

$0:=$filePath
