//%attributes = {"shared":true}
C_POINTER:C301($1;$effectNamePtr)  // @param: Pointer to the effect name.
C_POINTER:C301($2;$effectParamsPtr)  // @param: Pointer to the effect parameters.
C_TEXT:C284($3;$docRef)  // @param: The image document to use as preview. @optional
C_LONGINT:C283($4;$frameIdx)  // @param: The index of the image frame to use as preview. @optional
C_OBJECT:C1216($5;$dialogOptions)  // @param: Options. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Display a dialog where the user can select an image effect and
  // associated parameters.

  // @doc: Display a dialog where the user can select an image effect and
  // associated parameters.
  //
  // Parameters ``effectNamePtr`` and ``effectParamsPtr`` are pointers to text and object
  // respectively. On entry, they specify the effect name and parameters to be initially
  // selected in the dialog. If the user accepts the dialog, they receive the selected
  // name effect and parameters.
  //
  // Parameters ``docRef`` and ``frameIdx`` are optional and can be used to specify
  // the image to be displayed in the preview area of the dialog.
  //
  // The ``dialogOptions`` object parameter is also optional and can be used to customize
  // titles titles of the window and OK button:
  //
  // .. list-table::
  //    :widths: 25 25 50
  //    :header-rows: 1
  //
  //    * - Property name
  //      - Default
  //      - Description
  //    * - "WindowTitle"
  //      - "Select effect"
  //      - The window title.
  //    * - "OKButtonTitle"
  //      - "OK"
  //      - The OK button title.
  //
  // The method returns ``1`` if the user accepts the dialog, ``0`` otherwise.
  //

ASSERT:C1129(Count parameters:C259>=2)

$effectNamePtr:=$1
$effectParamsPtr:=$2
If (Count parameters:C259>2)
	$docRef:=$3
Else 
	$docRef:=""
End if 
If (Count parameters:C259>3)
	$frameIdx:=$4
Else 
	$frameIdx:=0
End if 
If (Count parameters:C259>4)
	$dialogOptions:=$5
End if 

$success:=0

If ($frameIdx=0)
	$frameIdx:=1
End if 

C_TEXT:C284(_pEffectDoc)
_pEffectDoc:=""

If ($docRef#"")
	
	_pEffectDoc:=ImgDoc_CreateNew 
	If (_pEffectDoc#"")
		If (ImgDoc_InsertFrame (_pEffectDoc;1;$docRef;$frameIdx)#1)
			ImgObj_Release:P11667:133 (_pEffectDoc)
			_pEffectDoc:=""
		End if 
	End if 
End if 

If (_pEffectDoc="")
	
	C_TEXT:C284($samplePath)
	$samplePath:=Get 4D folder:C485(Current resources folder:K5:16)+"EffectSample.jpg"
	If (Test path name:C476($samplePath)=Is a document:K24:1)
		
		_pEffectDoc:=ImgDoc_CreateWithFile (Convert path system to POSIX:C1106($samplePath))
		
	End if 
	
End if 

C_OBJECT:C1216(pEffectDialogOptions)
pEffectDialogOptions:=OB Copy:C1225($dialogOptions)

C_TEXT:C284(pEffectNameArg)
C_OBJECT:C1216(pEffectParamsArg)

pEffectNameArg:=$effectNamePtr->
If (OB Is defined:C1231($effectParamsPtr->))
	pEffectParamsArg:=OB Copy:C1225($effectParamsPtr->;True:C214)
End if 

_RasterEffect_LoadSpecs 

If (Size of array:C274(pEffectNames)>0)
	
	C_LONGINT:C283($effectIdx)
	$effectIdx:=Find in array:C230(pEffectNames;pEffectNameArg)
	If ($effectIdx<=0)
		
		pEffectNameArg:=pEffectNames{1}
		
	Else 
		
		If (OB Is defined:C1231(pEffectParamsArg))
			
			C_OBJECT:C1216($effectSpec)
			$effectSpec:=OB Get:C1224(pDialogEffects;pEffectNameArg;Is object:K8:27)
			
			C_OBJECT:C1216($paramValues)
			$paramValues:=OB Get:C1224($effectSpec;"ParamValues";Is object:K8:27)
			
			$paramValues:=OB_SimpleMerge ($paramValues;pEffectParamsArg)
			OB SET:C1220($effectSpec;"ParamValues";$paramValues)
			
		End if 
		
	End if 
	
	C_LONGINT:C283(pEffectWindow)
	pEffectWindow:=Open form window:C675("_ImgEffect";Movable form dialog box:K39:8;Horizontally centered:K39:1;Vertically centered:K39:4)
	
	DIALOG:C40("_ImgEffect")
	If (OK=1)
		
		$effectNamePtr->:=pEffectNameArg
		$effectParamsPtr->:=OB Copy:C1225(pEffectParamsArg)
		
		$success:=1
		
	End if 
	
	CLOSE WINDOW:C154(pEffectWindow)
	pEffectWindow:=0
	
End if 

If (_pEffectDoc#"")
	ImgObj_Release:P11667:133 (_pEffectDoc)
	_pEffectDoc:=""
End if 

$0:=$success

