//%attributes = {"shared":true}
C_POINTER:C301($1; $pictPtr)  // @param: A pointer to a picture.
C_OBJECT:C1216($2; $options)  // @param: Options. @optional
C_TEXT:C284($0; $imgDocRef)  // @param: The reference to the created image document instance.

// @desc: Create an image document instance referencing image data provided in a 4D picture.

// @doc: Create an image document instance referencing image data provided in a 4D picture.
// The image document reference is returned in ``imgDocRef``.
//
// If the method call fails for some reason, an empty string is returned and the
// Q2Pix error info is set accordingly.
//
// Parameter ``pictPtr`` is a pointer to a 4D picture.
//
// A 4D picture may contain multiple representations of the same image. This method finds
// the first representation in a supported format with the help of the
// :cc4d:xmethod:`PictUtil_GetImageFormats` plug-in method, extracts the
// representation's image data with a call to the :cc4d:xmethod:`PictUtil_GetImageData`
// plug-in method, and finally passes the image data to :cc4d:cmethod:`ImgDoc_CreateWithBLOB`.
//
// The optional ``options`` object parameter may contain the following key/value pairs:
//
// .. list-table::
//    :widths: 30 70
//    :header-rows: 1
//
//    * - Key
//      - Description
//    * - "Password"
//      - The option's value is the password (a string) for a protected PDF document.
//    * - "AllowUserInteraction"
//      - The option's value is a boolean denoting whether user interaction is allowed.
//        Default value is ``True``.
//
// If the selected image representation contains a locked PDF document and opening
// it fails with an authorization error (``"Q2Pix"``/``kQ2PixErrAuth``), a password entry dialog
// is presented to the user. If the user enters the correct password, the PDF document is opened
// and the document reference is returned. If the user cancels the dialog, the Q2Pix error info
// is set to ``"Q2Pix"``/``kQ2PixErrAuth`` and the method returns an empty string. If the user enters
// an invalid password, the method keeps running the password request dialog until the user either
// enters the correct dialog, or cancels.
//
// The ``AllowUserInteraction`` property defaults to ``True``, which allows this command to
// present the PDF password dialog, if necessary. When calling this
// method in a batch or unattended process, you may consider setting this to ``False`` so as the
// process is not halted by the dialog waiting for user input.
//


ASSERT:C1129(Count parameters:C259>=1)

$pictPtr:=$1
ASSERT:C1129(Type:C295($pictPtr->)=Is picture:K8:10)

If (Count parameters:C259>1)
	$options:=$2
End if 

ARRAY TEXT:C222($reprFormats; 0)
PictUtil_GetImageFormats:P11667:123($pictPtr->; $reprFormats)

C_TEXT:C284($formatID)
C_LONGINT:C283($reprIdx; $idx)
$reprIdx:=0
For ($idx; 1; Size of array:C274($reprFormats))
	If ($reprFormats{$idx}#"")
		$formatID:=$reprFormats{$idx}
		$reprIdx:=$idx
		$idx:=Size of array:C274($reprFormats)+1
	End if 
End for 

If ($formatID#"")
	
	C_BLOB:C604($reprData)
	$reprData:=PictUtil_GetImageData:P11667:124($pictPtr->; $reprIdx)
	If (BLOB size:C605($reprData)>0)
		
		C_OBJECT:C1216($localOptions)
		If (OB Is defined:C1231($options))
			$localOptions:=OB Copy:C1225($options)
		Else 
			$localOptions:=New object:C1471()
		End if 
		OB SET:C1220($localOptions; "Format"; $formatID)
		
		$imgDocRef:=ImgDoc_CreateWithBLOB(->$reprData; $localOptions)
		
	Else 
		
		C_OBJECT:C1216($errInfo)
		OB SET:C1220($errInfo; "Domain"; "Q2Pix"; "Code"; kQ2PixErrNoData; \
			"Method"; Current method name:C684)
		ImgErr_SetInfo($errInfo)
		
	End if 
	
Else 
	
	C_OBJECT:C1216($errInfo)
	OB SET:C1220($errInfo; "Domain"; "Q2Pix"; "Code"; kQ2PixErrCodec; \
		"Method"; Current method name:C684)
	ImgErr_SetInfo($errInfo)
	
End if 

$0:=$imgDocRef
