//%attributes = {"shared":true}
C_TEXT:C284($1; $imgDocRef)  // @param: The image document reference.
C_LONGINT:C283($2; $frameIdx)  // @param: The index of the image frame. @optional

// @desc: Copy the image frame to the pasteboard.

// @doc: Copy the image frame to the pasteboard.
// 
// Parameter ``imgDocRef`` is the image document reference.
// 
// Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
// parameter is the same as passing 1.
//

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

C_LONGINT:C283($frameCount)
$frameCount:=ImgDoc_GetFrameCount:P11667:11($imgDocRef)

If (($frameCount>0) & ($frameIdx>0) & ($frameIdx<=$frameCount))
	
	C_TEXT:C284($docFormat)
	$docFormat:=ImgDoc_GetFormat:P11667:9($imgDocRef)
	
	C_OBJECT:C1216($formatInfo)
	$formatInfo:=ImgFormat_GetInfo($docFormat)
	
	If (($docFormat="PDF") & Is macOS:C1572)
		
		C_OBJECT:C1216($encodeOptions)
		OB SET:C1220($encodeOptions; "Format"; "PDF")
		
		C_TEXT:C284($pbDocRef)
		$pbDocRef:=ImgDoc_CreateNew($encodeOptions)
		If ($pbDocRef#"")
			
			If (ImgDoc_InsertFrame($pbDocRef; 1; $imgDocRef; $frameIdx)=1)
				
				C_BLOB:C604($encodedData)
				$encodedData:=ImgDoc_SaveInBLOB($pbDocRef; $encodeOptions)
				If (BLOB size:C605($encodedData)>0)
					
					CLEAR PASTEBOARD:C402
					APPEND DATA TO PASTEBOARD:C403("com.adobe.pdf"; $encodedData)
					
				End if 
				
			End if 
			
			ImgObj_Release:P11667:133($pbDocRef)
		End if 
		
	Else 
		
		C_BOOLEAN:C305($canEncode)
		$canEncode:=OB Get:C1224($formatInfo; "CanEncode"; Is boolean:K8:9)
		
		C_TEXT:C284($encodeFormat)
		If (Is macOS:C1572)
			$encodeFormat:=Choose:C955($canEncode; $docFormat; "TIFF")
		Else 
			$encodeFormat:="TIFF"
		End if 
		
		C_OBJECT:C1216($pbFormatInfo)
		$pbFormatInfo:=ImgFormat_GetInfo($encodeFormat)
		
		C_OBJECT:C1216($encodeOptions)
		OB SET:C1220($encodeOptions; "Format"; $encodeFormat)
		
		C_TEXT:C284($pbDocRef)
		$pbDocRef:=ImgDoc_CreateNew($encodeOptions)
		If ($pbDocRef#"")
			
			If (ImgDoc_InsertFrame($pbDocRef; 1; $imgDocRef; $frameIdx)=1)
				
				C_BLOB:C604($encodedData)
				$encodedData:=ImgDoc_SaveInBLOB($pbDocRef; $encodeOptions)
				If (BLOB size:C605($encodedData)>0)
					
					C_TEXT:C284($pbUTI)
					$pbUTI:=OB Get:C1224($pbFormatInfo; "UTI"; Is text:K8:3)
					
					If (Is macOS:C1572 & ($pbUTI#""))
						
						CLEAR PASTEBOARD:C402
						APPEND DATA TO PASTEBOARD:C403($pbUTI; $encodedData)
						
					Else 
						C_PICTURE:C286($encodedPict)
						BLOB TO PICTURE:C682($encodedData; $encodedPict)
						
						If (Picture size:C356($encodedPict)>0)
							
							SET PICTURE TO PASTEBOARD:C521($encodedPict)
							
						End if 
					End if 
					
				End if 
				
			End if 
			
			ImgObj_Release:P11667:133($pbDocRef)
		End if 
		
	End if 
	
End if   // (($frameCount>0) & ($frameIdx>0) & ($frameIdx<=$frameCount))

