//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The image document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the image frame. @optional
C_OBJECT:C1216($0;$geometry)

  // @desc: Return the geometry of an image frame.

  // @doc: Return an object describing the geometric characteristics of an image frame.
  //
  // Parameter ``imgDocRef`` is the image document reference. This method works with both raster
  // images and PDF documents.
  //
  // Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
  // parameter is the same as passing 1.
  //
  // The geometry of the image frame is returned as an object in ``geometry``.
  // The contents of the geometry object depend on the kind of the image
  // document, described in the following tables.
  //
  // .. include:: /_shared/ImgFrame_Geometry.rsti
  //
  // .. note:: This utility method is a wrapper for the :cc4d:xmethod:`ImgFrame_GetGeometry_JSN` plug-in method.
  //           There is little reason to call this method directly as there are specialized methods for accessing
  //           the geometric characteristics of image frames, with the added benefit of presenting those in the
  //           frame's oriented coordinate space by default: :cc4d:cmethod:`ImgFrame_GetPointSize`,
  //           :cc4d:cmethod:`RasterFrame_GetPixelSize`, :cc4d:cmethod:`RasterFrame_GetDPISize`,
  //           :cc4d:cmethod:`RasterFrame_GetOrientation`.
  //

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

C_TEXT:C284($geometryJSON)
$geometryJSON:=ImgFrame_GetGeometry_JSN:P11667:21 ($imgDocRef;$frameIdx)
If ($geometryJSON#"")
	JSON_Parse (->$geometryJSON;->$geometry)
End if 

$0:=$geometry
