//%attributes = {"shared":true}
C_TEXT:C284($1; $imgDocRef)  // @param: The image document reference.
C_LONGINT:C283($2; $frameIdx)  // @param: The index of the image frame. @optional
C_BOOLEAN:C305($3; $oriented)  // @param: Return the point size in the oriented image coordinate space. @optional
C_OBJECT:C1216($0; $pointSize)  // @param: The image frame's size in *points*.

// @desc: Return the image frame's size in *points*.

// @doc: Return the image frame's size in *points*.
//
// Parameter ``imgDocRef`` is the image document reference. This method works with both raster
// images and PDF documents.
//
// Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
// parameter is the same as passing 1.
//
// Parameter ``oriented`` specifies whether the returned frame size will
// be expressed in the oriented or in the raw image frame coordinate space.
// Optional, default is ``True``.
//
// The requested size is returned in ``pointSize`` as a ``SizeObj`` 4D object
// and it is expressed in typographic ``points``, where 1 ``point`` is a 1/72 of an ``inch``.
//

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

If (Count parameters:C259>2)
	$oriented:=$3
Else 
	$oriented:=True:C214
End if 

C_OBJECT:C1216($geometry)
$geometry:=ImgFrame_GetGeometry($imgDocRef; $frameIdx)
If (OB Is defined:C1231($geometry))
	
	$pointSize:=OB Get:C1224($geometry; "PointSize"; Is object:K8:27)
	If (OB Is defined:C1231($pointSize) & $oriented)
		
		C_BOOLEAN:C305($swap)
		$swap:=False:C215
		
		If (ImgDoc_GetFormat:P11667:9($imgDocRef)="PDF")
			
			C_LONGINT:C283($rotation)
			$rotation:=Choose:C955($geometry["Rotation"]#Null:C1517; $geometry["Rotation"]; 0)
			$swap:=(($rotation=90) | ($rotation=270))
			
		Else 
			
			C_LONGINT:C283($orientation)
			$orientation:=OB Get:C1224($geometry; "Orientation"; Is longint:K8:6)
			$swap:=(($orientation=kImgRotatedLeft)\
				 | ($orientation=kImgRotatedRight)\
				 | ($orientation=kImgRotatedLeftFlippedVert)\
				 | ($orientation=kImgRotatedRightFlippedVert))
			
		End if 
		
		If ($swap)
			
			C_REAL:C285($width; $height)
			$width:=OB Get:C1224($pointSize; "Width"; Is real:K8:4)
			$height:=OB Get:C1224($pointSize; "Height"; Is real:K8:4)
			
			OB SET:C1220($pointSize; "Width"; $height; "Height"; $width)
			
		End if 
		
	End if 
	
End if 

$0:=$pointSize
