//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame.
C_OBJECT:C1216($3;$cropRect)  // @param: The crop rectangle.
C_BOOLEAN:C305($4;$oriented)  // @param: Whether ``cropRect`` is expressed in the oriented or raw image coordinate space. @optional

  // @desc: Crop a raster frame.

  // @doc: Crop the raster frame specified by ``imgDocRef`` and ``frameIdx``.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame.
  //
  // The crop rectangle is specified by the ``cropRect`` parameter, which is a ``RectObj`` object
  // expressed in ``pixels``.
  //
  // .. note:: This method is a convenience wrapper for the :cc4d:cmethod:`RasterFrame_PushFilter` method
  //           that pushes the ``Crop`` filter into the raster frame's edit stack.
  //

ASSERT:C1129(Count parameters:C259>=3)

$imgDocRef:=$1
$frameIdx:=$2
$cropRect:=$3
If (Count parameters:C259>3)
	$oriented:=$4
Else 
	$oriented:=True:C214
End if 

If ((RectObj_GetWidth ($cropRect)>0) & (RectObj_GetHeight ($cropRect)>0))
	
	C_OBJECT:C1216($filterParams)
	OB SET:C1220($filterParams;"Rectangle";$cropRect)
	OB SET:C1220($filterParams;"Oriented";$oriented)
	
	RasterFrame_PushFilter ($imgDocRef;$frameIdx;"Crop";$filterParams)
	
Else 
	
	C_OBJECT:C1216($errInfo)
	OB SET:C1220($errInfo;"Domain";"Q2Pix";"Code";kQ2PixErrInvalid;\
		"Method";Current method name:C684)
	ImgErr_SetInfo ($errInfo)
	
End if 

