//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame. @optional
C_BOOLEAN:C305($3;$oriented)  // @param: Return the DPI size in the oriented image coordinate space. @optional
C_OBJECT:C1216($0;$dpiSize)  // @param: The image frame's DPI size in ``pixels per inch``.

  // @desc: Return the resolution of a raster frame.

  // @doc: Return the resolution of the raster frame specified by ``imgDocRef`` and ``frameIdx``
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, an undefined 4D object is returned.
  //
  // Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
  // parameter is the same as passing 1.
  //
  // The optional ``oriented`` parameter specified whether to return the frame's resolution
  // in the oriented or raw image coordinate space. The default value is ``True``.
  //
  // The raster frame's resolution is returned in ``dpiSize`` as a ``SizeObj`` object.
  // The ``Width`` and ``Height`` properties of ``dpiSize`` are expressed in
  // ``pixels per inch`` and represent the horizontal and vertical resolution respectively.
  //

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

If (Count parameters:C259>2)
	$oriented:=$3
Else 
	$oriented:=True:C214
End if 

C_OBJECT:C1216($geometry)
$geometry:=ImgFrame_GetGeometry ($imgDocRef;$frameIdx)
If (OB Is defined:C1231($geometry))
	
	$dpiSize:=OB Get:C1224($geometry;"DPISize";Is object:K8:27)
	If (OB Is defined:C1231($dpiSize) & $oriented)
		
		C_LONGINT:C283($orientation)
		$orientation:=OB Get:C1224($geometry;"Orientation";Is longint:K8:6)
		If (($orientation=kImgRotatedLeft) | ($orientation=kImgRotatedRight) | ($orientation=kImgRotatedLeftFlippedVert) | ($orientation=kImgRotatedRightFlippedVert))
			
			$dpiSize:=SizeObj_New (SizeObj_GetHeight ($dpiSize);SizeObj_GetWidth ($dpiSize))
			
		End if 
		
	End if 
	
End if 

$0:=$dpiSize
