//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame.
C_REAL:C285($3;$scaleX)  // @param: The horizontal scale factor.
C_REAL:C285($4;$scaleY)  // @param: The vertical scale factor. @optional
C_BOOLEAN:C305($5;$oriented)  // @param: Whether ``scaleX`` and ``scaleY`` are expressed in the oriented or raw image coordinate space. @optional

  // @desc: Scale the pixel map of a raster frame.

  // @doc: Scale the pixel map of the raster frame specified by ``imgDocRef`` and ``frameIdx``.
  //
  // High quality raster scaling is achieved by using the ``Lanczos`` *Core Image* filter on
  // macOS, and the ``Scale`` *Direct2D* effect with *high quality bicubic interpolation*
  // on Windows.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame.
  //
  // The horizontal and vertical scale factors are specified by the ``scaleX`` and ``scaleY``
  // parameters respectively. If ``scaleY`` is omitted, it takes the value of ``scaleX``.
  //
  // Parameter ``oriented`` specifies whether the ``scaleX`` and ``scaleY`` factors
  // be expressed in the oriented or in the raw image frame coordinate space.
  // Optional, default is ``True``.
  //
  // .. note:: This method is a convenience wrapper for the :cc4d:cmethod:`RasterFrame_PushFilter` method
  //           that pushes the ``Scale`` filter into the raster frame's edit stack.
  //

ASSERT:C1129(Count parameters:C259>=3)

$imgDocRef:=$1
$frameIdx:=$2
$scaleX:=$3
If (Count parameters:C259>3)
	$scaleY:=$4
Else 
	$scaleY:=$scaleX
End if 
If (Count parameters:C259>4)
	$oriented:=$5
Else 
	$oriented:=True:C214
End if 

If (($scaleX>0) & ($scaleY>0))
	
	C_OBJECT:C1216($filterParams)
	OB SET:C1220($filterParams;"ScaleX";$scaleX)
	OB SET:C1220($filterParams;"ScaleY";$scaleY)
	OB SET:C1220($filterParams;"Oriented";$oriented)
	
	RasterFrame_PushFilter ($imgDocRef;$frameIdx;"Scale";$filterParams)
	
Else 
	
	C_OBJECT:C1216($errInfo)
	OB SET:C1220($errInfo;"Domain";"Q2Pix";"Code";kQ2PixErrInvalid;\
		"Method";Current method name:C684)
	ImgErr_SetInfo ($errInfo)
	
End if 

