//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame.
C_OBJECT:C1216($3;$dpiSize)  // @param: The new DPI size of the frame.
C_BOOLEAN:C305($4;$oriented)  // @param: Whether the ``dpiSize`` is expressed in the oriented or raw image coordinate space. @optional

  // @desc: Change the resolution of a raster frame.

  // @doc: Change the resolution of the raster frame specified by ``imgDocRef`` and ``frameIdx``.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame.
  //
  // The new resolution is specified by the ``dpiSize`` parameter, which is a ``SizeObj`` object
  // with its ``Width`` and ``Height`` properties expressed in ``pixels per inch`` and representing
  // the new horizontal and vertical resolution respectively.
  //
  // .. note:: This method is a convenience wrapper for the :cc4d:cmethod:`RasterFrame_PushFilter` method
  //           that pushes the ``Resolution`` filter into the raster frame's edit stack.
  //

ASSERT:C1129(Count parameters:C259>=3)

$imgDocRef:=$1
$frameIdx:=$2
$dpiSize:=$3
If (Count parameters:C259>3)
	$oriented:=$4
Else 
	$oriented:=True:C214
End if 

If ((SizeObj_GetWidth ($dpiSize)>=1) & (SizeObj_GetHeight ($dpiSize)>=1))
	
	C_OBJECT:C1216($filterParams)
	OB SET:C1220($filterParams;"DPISize";$dpiSize)
	OB SET:C1220($filterParams;"Oriented";$oriented)
	
	RasterFrame_PushFilter ($imgDocRef;$frameIdx;"Resolution";$filterParams)
	
Else 
	
	C_OBJECT:C1216($errInfo)
	OB SET:C1220($errInfo;"Domain";"Q2Pix";"Code";kQ2PixErrInvalid;\
		"Method";Current method name:C684)
	ImgErr_SetInfo ($errInfo)
	
End if 

